#
# spec file for package python-sidpy
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define packagename sidpy
%{?!python_module:%define python_module() python3-%{**}}
%define skip_python2 1
Name:           python-sidpy
Version:        0.0.8
Release:        2.3
Summary:        Utilities for processing Spectroscopic and Imaging Data
License:        MIT
URL:            https://pycroscopy.github.io/sidpy/
Source:         https://github.com/pycroscopy/sidpy/archive/%{version}.tar.gz#/%{packagename}-%{version}.tar.gz
BuildRequires:  %{python_module cytoolz}
BuildRequires:  %{python_module dask >= 0.10}
BuildRequires:  %{python_module dask-array >= 0.10}
BuildRequires:  %{python_module distributed >= 2}
BuildRequires:  %{python_module h5py >= 2.6.0}
BuildRequires:  %{python_module ipyfilechooser >= 0.0.6}
BuildRequires:  %{python_module ipywidgets >= 5.2.2}
BuildRequires:  %{python_module joblib >= 0.11.0}
BuildRequires:  %{python_module matplotlib >= 2.0.0}
BuildRequires:  %{python_module mpi4py}
BuildRequires:  %{python_module numpy >= 1.10}
BuildRequires:  %{python_module psutil}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module qt5}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  %{python_module toolz}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-cytoolz
Requires:       python-dask >= 0.10
Requires:       python-dask-array >= 0.10
Requires:       python-distributed >= 2
Requires:       python-h5py >= 2.6.0
Requires:       python-ipyfilechooser >= 0.0.6
Requires:       python-ipywidgets >= 5.2.2
Requires:       python-joblib >= 0.11.0
Requires:       python-matplotlib >= 2.0.0
Requires:       python-mpi4py
Requires:       python-numpy >= 1.10
Requires:       python-psutil
Requires:       python-qt5
Requires:       python-six
Requires:       python-toolz
BuildArch:      noarch
%python_subpackages

%description
Python utilities for storing, visualizing, and processing Spectroscopic and Imaging Data (SID).

%prep
%setup -q -n %{packagename}-%{version}
# https://github.com/pycroscopy/sidpy/issues/142
sed -i 's:pytest-runner:pytest:' setup.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/%{packagename}-%{version}*-info
%{python_sitelib}/%{packagename}

%changelog
* Tue Apr 26 2022 Steve Kowalik <steven.kowalik@suse.com>
- Remove skip for Python 3.10, dask is now available.
* Sun Feb  6 2022 Ben Greiner <code@bnavigator.de>
- Update to 0.0.8
  * Support of thumbnails for icon view of directory
  * updated for new version of ipyfilechooser
  * better support of dask functions (thanks Mani).
  * nested dictionaries are now written and read from hdf5 files
  * support of 4D image sets in plotting.
  * Minor bug fixes
* Sat Feb  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Skip build for python 3.10: python-dask is not (yet) compatible.
* Tue Dec 14 2021 pgajdos@suse.com
- pytest-runner is not required for build
* Wed Apr 14 2021 andy great <andythe_great@pm.me>
- Update to version 0.0.5.
  * Mathematical operations return sidpy.Dataset now instead of
    dask.array.
* Mon Jan 18 2021 andy great <andythe_great@pm.me>
- Disable build for python 2 and python3.6 because numpy and scipy
  don't support them.
* Mon Dec 21 2020 andy great <andythe_great@pm.me>
- Update to version 0.0.4a.
  * range of bug fixes
  * greatly expanded tests
  * added ore docstrings
  * simplified imports and removed unnecessary functions
  * compatibility with single core machines
  * changes to write_simple_attrs method, to now include ability to write enum objects
  * changes to minimum dimension size
* Mon Nov 23 2020 andy great <andythe_great@pm.me>
- Update to version 0.0.3.
  * sidpy.Dataset extend dask.array
  * sidpy.Dimension extends numpy.ndarray
  * Improved unit testing for core functions
* Fri Sep 18 2020 andy great <andythe_great@pm.me>
- Remove fix_tests_dir_in_site_package.patch, fix in sidpy 0.0.2.
- Update to version 0.0.2.
  * Submodules of the main modules can be imported directly.
    E.g. import sidpy.hdf_utils instead of sidpy.hdf.hdf_utils
  * Preventing tests from being deployed into site-packages
  * Fixed bugs in sidpy.io.interface_utils.py that was causing
    problems when importing sidpy
  * Added python 3.8 support and testing
  * Improvements and bug fixes to dataset.py
  * Added plotting utilities written to support upcoming
    Dataset.plot().
  * Ported additional hdf_utils functions for copying datasets
    (now in hdf_utils) and provenance tracking within HDF files
    (now in prov_utils)
  * Added Reader class to do half the job of the existing
    Translator class
  * Translator class now shows a deprecation warning prompting
    users to start using Reader instead and populate ScopeReaders
* Fri Aug 14 2020 andy great <andythe_great@pm.me>
- Initial package release.
